@@ -9,12 +9,9 @@
 #ifndef LLDB_HOST_CONFIG_H
 #define LLDB_HOST_CONFIG_H
 
-#define LLDB_EDITLINE_USE_WCHAR 1
+#define LLDB_EDITLINE_USE_WCHAR 0
 
-#define LLDB_HAVE_EL_RFUNC_T 1
-
-
-#define HAVE_SYS_TYPES_H 1
+#define LLDB_HAVE_EL_RFUNC_T 0
 
 #define HAVE_SYS_EVENT_H 0
 
@@ -22,8 +19,6 @@
 
 #define HAVE_PTSNAME_R 1
 
-#define HAVE_SIGACTION 1
-
 #define HAVE_PROCESS_VM_READV 1
 
 #define HAVE_NR_PROCESS_VM_READV 1
@@ -42,7 +37,7 @@
 
 #define CURSES_HAVE_NCURSES_CURSES_H 0
 
-#define LLDB_ENABLE_LIBEDIT 1
+#define LLDB_ENABLE_LIBEDIT 0
 
 #define LLDB_ENABLE_LIBXML2 1
 
@@ -50,10 +45,14 @@
 
 #define LLDB_ENABLE_PYTHON 1
 
+#define LLDB_ENABLE_FBSDVMCORE 0
+
 #define LLDB_EMBED_PYTHON_HOME 0
 
 /* #undef LLDB_PYTHON_HOME */
 
 #define LLDB_LIBDIR_SUFFIX ""
 
+/* #undef LLDB_GLOBAL_INIT_DIRECTORY */
+
 #endif // #ifndef LLDB_HOST_CONFIG_H
